@@ -1,6 +1,6 @@
 """
 This sub-module holds the classes for the configuration management.
 """
-from .config import Config, ConfigEntry, CliEntry
+from .config import Config, ConfigEntry, CliEntry, json_string
 
 __all__ = ["config"]
